;Function CPROP
;
;Called with a required argument, which must be a valid
;entity association list.
;
;Changes current LAYER, LINETYPE, THICKNESS, and COLOR settings
;to those contained within the entity association list
;supplied as an argument.

(defun cprop (elist)
  (command "LAYER" "S" (cdr (assoc 8 elist)) "")
  (if
    (assoc 6 elist)
    (command "LINETYPE" "S" (cdr (assoc 6 elist)) "")
    (command "LINETYPE" "S" "bylayer" "")
  )
  (if
    (assoc 39 elist)
    (command "ELEV" 0 (cdr (assoc 39 elist)))
    (command "ELEV" 0 0)
  )
  (cond                          ;added test for color byblock
    ((not (assoc 62 elist))
     (command "COLOR" "bylayer")
    )
    ((= 0 (cdr (assoc 62 elist)))
     (command "COLOR" "byblock")
    )
    (t (command "COLOR" (cdr (assoc 62 elist))))
  )
)

;Function C:DENT  Draw ENTity
;
;For AutoCAD Release 10
;
;DENT prompts user to select an entity, and passes the
;entity association list of the selected entity to the
;function CPROP.  Upon return from CPROP, DENT issues
;an AutoCAD command to draw the same type of entity as
;the one selected.
;
;This function is not fully de-bugged, and I expect you to
;encounter some situations where you will want to implement
;changes to this code.  Please be my guest and modify this
;to your heart's content.  I refuse to honor any requests for
;feature changes or bug fixes to this code; you're on
;your own.  Have fun!
;
;Written by Brad Zehring
;Tuesday  March 21, 1989  7:45 pm  Sausalito, California
;Modified 6/13/89
;
;Based on an idea from Creighton Hoke

(defun C:DENT (/ old_cmdecho ename elist etype)
  (setq old_cmdecho (getvar "CMDECHO"))
  (setvar "CMDECHO" 0)
  (if
    (setq ename (entsel))
    (progn
      (setq ename (car ename)
            elist (entget ename)
            etype (cdr (assoc 0 elist))
      )
      (cprop elist)
      (setvar "CMDECHO" 1)
      (cond
        ((eq "TEXT" etype)
         (menucmd "S=X")    ;added ACAD.MNU screen menu calls
         (menucmd "S=TEXT")
         (if                ;style height non-zero?
           (/= 0 
             (cdr 
               (assoc 40 
                 (tblsearch "STYLE" (cdr (assoc 7 elist)))
               )
             )
           )
           (command "DTEXT" "Style" (cdr (assoc 7 elist))
                            pause
                            (/ (* 180 (cdr (assoc 50 elist))) pi)
           )
           (command "DTEXT" "Style" (cdr (assoc 7 elist))
                            pause
                            (cdr (assoc 40 elist))
                            (/ (* 180 (cdr (assoc 50 elist))) pi)
           )
         )
        )
        ((eq "POLYLINE" etype)
         (menucmd "S=X")
         (menucmd "S=PLINE")
         (command "PLINE")
        )
        ((eq "INSERT" etype)
         (menucmd "S=X")
         (menucmd "S=INSERT")
         (command "INSERT" (cdr (assoc 2 elist)))
        )
        ((eq "DIMENSION" etype)
         (menucmd "S=X")
         (menucmd "S=DIM")
         (command "DIM1")
        )
        (t 
         (menucmd "S=X")
         (menucmd (strcat "S=" etype))
         (command etype)
        )
      )
    )
  )
  (setvar "CMDECHO" old_cmdecho)
  (prin1)
)
